Find.Markers.Each: Find.Markers.Each

Description Usage Arguments Value

View source: R/DE_analysis.R

Description

A wrapper function to output: For each condition in the "stim" field, each cluster's marker that are significantly overexpressed in a given cluster compared to the rest of the clusters

Usage

1
2
Find.Markers.Each(seurat.ob, min.pct = 0.1, logfc.threshold = 0.3,
  multi = NA)

Arguments

seurat.ob

The seurat object with clustering information

min.pct

as in Seurat::FindAllMarkers function

logfc.threshold

the minimum log fold change threshold to detect differentially expressed change

multi

if "stim" field is not "CTRL" VS "STIM", then the multi field would take in a vector with the name of the stim conditions

Value

a object for each stim condition, stored in a ret object list


steveyu323/SEURATEXT documentation built on Nov. 5, 2019, 9:38 a.m.