Plot.FeatureScatter: Plot.FeatureScatter

Description Usage Arguments Value

View source: R/cell_cytometry.R

Description

Wrapper function for the Seurat.FeatureScatter for 2 different conditions

Usage

1
Plot.FeatureScatter(seurat.ob, x, y)

Arguments

seurat.ob

a seurat object type that have a count a count table inside with proper column name as cells and rowname as the gene

x

The gene name of the first cell marker

y

The gene name of the second cell marker

Value

a grid-arranged FeatureScatter Seurat plot


steveyu323/SEURATEXT documentation built on Nov. 5, 2019, 9:38 a.m.