Description Usage Arguments Value
A wrapper function to output: For each condition in the "stim" field, each cluster's marker that are significantly overexpressed in a given cluster compared to the rest of the clusters
1 2 | Find.Markers.Each(seurat.ob, min.pct = 0.1, logfc.threshold = 0.3,
multi = NA)
|
seurat.ob |
The seurat object with clustering information |
min.pct |
as in Seurat::FindAllMarkers function |
logfc.threshold |
the minimum log fold change threshold to detect differentially expressed change |
multi |
if "stim" field is not "CTRL" VS "STIM", then the multi field would take in a vector with the name of the stim conditions |
a object for each stim condition, stored in a ret object list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.