Description Usage Arguments Value
View source: R/cell_cytometry.R
Wrapper function for the Seurat.FeatureScatter for 2 different conditions
1 | Plot.FeatureScatter(seurat.ob, x, y)
|
seurat.ob |
a seurat object type that have a count a count table inside with proper column name as cells and rowname as the gene |
x |
The gene name of the first cell marker |
y |
The gene name of the second cell marker |
a grid-arranged FeatureScatter Seurat plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.